window.Gleam.initSearch([{"doc":"sprocket","title":"sprocket","content":"# Sprocket\nA library for building live views and real-time server components in [Gleam ✨](https://gleam.run/)\n\n[![Package Version](https://img.shields.io/hexpm/v/sprocket)](https://hex.pm/packages/sprocket)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/sprocket/)\n\n[Demo Documentation](https://sprocket.live)\n\nHeavily inspired by [Phoenix LiveView](https://github.com/phoenixframework/phoenix_live_view),\n[React](https://github.com/facebook/react) and [Elm](https://github.com/elm). The name &quot;sprocket&quot;\nis loosely derived from the metaphor of a bicycle&#39;s sprocket, cassette and chain.\n\nSprocket combines the best of LiveView server-side productivity and scalability, React components\nand Elm functional state management patterns implemented in Gleam, a type-safe\nlanguage built on the venerable BEAM (Erlang Virtual Machine).\n\nAn initial static view is rendered as HTML on the &quot;first paint&quot; which then establishes a connection to the server over a\nWebSocket to facilitate sending browser events and receiving view update diffs. These updates are\npatched into a client-side in-memory representation of the DOM and rendered to the browser using\nmorphdom. Declarative views are built using functional components that accept props and re-render\neach time those props change and reducers are used for state management using strongly-typed models\nand message structs.\n\nUnder the hood, a reducer is a lightweight [Gleam\nActor](https://hexdocs.pm/gleam_otp/0.1.3/gleam/otp/actor/) OTP process (i.e. gen_server) and\nchanges to the state (via dispatch) result in a re-render of the view.\n\nComponent interfaces snap together and are used to create higher-level views. Data flow is\n&quot;uni-directional&quot; in that **State** always flows down into components as props while **Events**\nflow up out of components through event handlers (which are also passed in as props, e.g.\n`on_some_event(&quot;Something happened&quot;)`). \n\nThis library is currently in a **proof of concept** state and should be considered highly unstable.\nThere is still a lot of work to be done, including adding support for more event types, introducing additional hooks, improving unit test\ncoverage, providing extensive documentation of modules and API, and optimizing performance. \n\n## Key Features\n\n- Real-time, scalable server-side component library\n- Renders initial HTML and efficiently patches update diffs using a persistent WebSocket connection\n- Declarative and composable functional components that re-render when props change\n- Strongly-typed language means less runtime bugs and better peace of mind\n- Lightweight OTP processes used for composable &amp; scalable state management\n\n## Example\n\n### Clock Component\n```gleam\ntype Model {\n  Model(time: Int, timezone: String)\n}\n\ntype Msg {\n  NoOp\n  UpdateTime(Int)\n}\n\nfn update(model: Model, msg: Msg) -&gt; Model {\n  case msg {\n    NoOp -&gt; model\n    UpdateTime(time) -&gt; {\n      Model(..model, time: time)\n    }\n  }\n}\n\nfn initial() -&gt; Model {\n  Model(time: erlang.system_time(erlang.Second), timezone: &quot;UTC&quot;)\n}\n\npub type ClockProps {\n  ClockProps(label: Option(String))\n}\n\npub fn clock(ctx: Context, props) {\n  let ClockProps(label) = props\n\n  // Define a reducer to handle events and update the state\n  use ctx, State(Model(time: time, ..), dispatch) &lt;- reducer(\n    ctx,\n    initial(),\n    update,\n  )\n\n  // Example effect that runs whenever the `time` variable changes and has a cleanup function\n  use ctx &lt;- effect(\n    ctx,\n    fn() {\n      let cancel =\n        interval(\n          1000,\n          fn() { dispatch(UpdateTime(erlang.system_time(erlang.Second))) },\n        )\n\n      Some(fn() { cancel() })\n    },\n    WithDeps([dep(time)]),\n  )\n\n  let current_time = int.to_string(time)\n\n  render(\n    ctx,\n    case label {\n      Some(label) -&gt; [span([], [text(label)]), span([], [text(current_time)])]\n      None -&gt; [text(current_time)]\n    },\n  )\n}\n```\n\n### Parent view\n```gleam\npub type ExampleViewProps {\n  ExampleViewProps\n}\n\npub fn example_view(ctx: Context, _props: ExampleViewProps) {\n  render(\n    ctx,\n    [\n      html(\n        [lang(&quot;en&quot;)],\n        [\n          head([], [link([rel(&quot;stylesheet&quot;), href(&quot;/app.css&quot;)])]),\n          body(\n            [class(&quot;bg-white dark:bg-gray-900 dark:text-white p-4&quot;)],\n            [\n              component(\n                clock,\n                ClockProps(label: Some(&quot;The current time is: &quot;)),\n              ),\n            ],\n          ),\n        ],\n      ),\n    ],\n  )\n}\n\n```\n\n## Getting Started\n\nTo get started with Sprocket, follow the instructions below:\n\n1. Clone the Sprocket repository:\n```sh\ngit clone https://github.com/eliknebel/sprocket.git\n```\n\n2. Install the required dependencies:\n```sh\ngleam deps download\nyarn\n```\n\n3. Start the development server:\n```sh\nyarn run watch\n```\n\n4. Open your web browser and visit [http://localhost:3000](http://localhost:3000) to see the docs sample app.\n\n\n## Installation\n\nThis package can be added to your Gleam project:\n\n```sh\ngleam add sprocket\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/sprocket&gt;.\n\n\n## Documentation\n\nDocumentation for Sprocket can be found at the [docs sample app](https://sprocket.live).\nIt provides detailed information on how to use Sprocket, including module descriptions, API \nreferences, and examples.\n\n## Roadmap\n\nSprocket is still in its early stages and has a roadmap for future development. Here are some of the planned improvements:\n\n- [x] Build out full set of base HTML functions for components\n- [ ] Explore [other http and websocket server options](https://hexdocs.pm/espresso/)\n- [ ] Add support for additional event types to handle various user interactions\n- [ ] Expand the available hooks to enable more flexible component behavior\n- [ ] Convert client TypeScript to gleam\n- [ ] Improve unit test coverage to ensure code quality and reliability\n- [ ] Provide extensive documentation of modules and API for easier adoption\n- [ ] Optimize performance to enhance responsiveness and scalability\n- [ ] Investigate extending to support more than just web views, such as native desktop, iOS, and Android applications.\n\n## Contributing\n\nContributions to Sprocket are welcome and encouraged! If you would like to contribute, please follow\nthe guidelines outlined in the\n[CONTRIBUTING.md](https://github.com/eliknebel/sprocket/blob/master/CONTRIBUTING.md) file.\n\n## License\n\nSprocket is released under the [MIT License](https://github.com/eliknebel/sprocket/blob/master/LICENSE.md).\n","url":"index.html"},{"doc":"sprocket/hooks","title":"CallbackResult","content":"pub type CallbackResult {\n  CallbackResult(\n    callback: CallbackFn,\n    deps: Option(HookDependencies),\n  )\n}\n\nCallbackResult(\n  callback: CallbackFn,\n  deps: Option(HookDependencies),\n)\n\n\nSynonyms:\nsprocket/hooks.CallbackResult\nsprocket/hooks CallbackResult","url":"sprocket/hooks.html#CallbackResult"},{"doc":"sprocket/hooks","title":"Compared","content":"pub type Compared(a) {\n  Changed(changed: a)\n  Unchanged\n}\n\nChanged(changed: a)\n\n\nUnchanged\n\n\nSynonyms:\nsprocket/hooks.Compared\nsprocket/hooks Compared","url":"sprocket/hooks.html#Compared"},{"doc":"sprocket/hooks","title":"EffectCleanup","content":"pub type EffectCleanup =\n  Option(fn() -&gt; Nil)\n\n\nSynonyms:\nsprocket/hooks.EffectCleanup\nsprocket/hooks EffectCleanup","url":"sprocket/hooks.html#EffectCleanup"},{"doc":"sprocket/hooks","title":"EffectResult","content":"pub type EffectResult {\n  EffectResult(\n    cleanup: EffectCleanup,\n    deps: Option(HookDependencies),\n  )\n}\n\nEffectResult(\n  cleanup: EffectCleanup,\n  deps: Option(HookDependencies),\n)\n\n\nSynonyms:\nsprocket/hooks.EffectResult\nsprocket/hooks EffectResult","url":"sprocket/hooks.html#EffectResult"},{"doc":"sprocket/hooks","title":"Hook","content":"pub type Hook {\n  Callback(\n    id: Unique,\n    callback: CallbackFn,\n    trigger: HookTrigger,\n    prev: Option(CallbackResult),\n  )\n  Effect(\n    id: Unique,\n    effect: fn() -&gt; EffectCleanup,\n    trigger: HookTrigger,\n    prev: Option(EffectResult),\n  )\n  Reducer(id: Unique, reducer: Dynamic, cleanup: fn() -&gt; Nil)\n  State(id: Unique, value: Dynamic)\n}\n\nCallback(\n  id: Unique,\n  callback: CallbackFn,\n  trigger: HookTrigger,\n  prev: Option(CallbackResult),\n)\n\n\nEffect(\n  id: Unique,\n  effect: fn() -&gt; EffectCleanup,\n  trigger: HookTrigger,\n  prev: Option(EffectResult),\n)\n\n\nReducer(id: Unique, reducer: Dynamic, cleanup: fn() -&gt; Nil)\n\n\nState(id: Unique, value: Dynamic)\n\n\nSynonyms:\nsprocket/hooks.Hook\nsprocket/hooks Hook","url":"sprocket/hooks.html#Hook"},{"doc":"sprocket/hooks","title":"HookDependencies","content":"pub type HookDependencies =\n  List(Dynamic)\n\n\nSynonyms:\nsprocket/hooks.HookDependencies\nsprocket/hooks HookDependencies","url":"sprocket/hooks.html#HookDependencies"},{"doc":"sprocket/hooks","title":"HookTrigger","content":"pub type HookTrigger {\n  OnMount\n  OnUpdate\n  WithDeps(deps: HookDependencies)\n}\n\nOnMount\n\n\nOnUpdate\n\n\nWithDeps(deps: HookDependencies)\n\n\nSynonyms:\nsprocket/hooks.HookTrigger\nsprocket/hooks HookTrigger","url":"sprocket/hooks.html#HookTrigger"},{"doc":"sprocket/hooks","title":"compare_deps","content":"pub fn compare_deps(prev_deps: List(Dynamic), deps: List(Dynamic)) -&gt; Compared(\n  List(Dynamic),\n)\n\nSynonyms:\nsprocket/hooks.compare_deps\nsprocket/hooks compare_deps","url":"sprocket/hooks.html#compare_deps"},{"doc":"sprocket/hooks","title":"dep","content":"pub fn dep(dependency: a) -&gt; Dynamic\n\nSynonyms:\nsprocket/hooks.dep\nsprocket/hooks dep","url":"sprocket/hooks.html#dep"},{"doc":"sprocket/hooks","title":"sprocket/hooks","content":"","url":"sprocket/hooks.html"},{"doc":"sprocket/html/attributes","title":"Attribute","content":"pub type Attribute {\n  Attribute(name: String, value: Dynamic)\n  Event(name: String, identifiable_cb: IdentifiableCallback)\n}\n\nAttribute(name: String, value: Dynamic)\n\n\nEvent(name: String, identifiable_cb: IdentifiableCallback)\n\n\nSynonyms:\nsprocket/html/attributes.Attribute\nsprocket/html/attributes Attribute","url":"sprocket/html/attributes.html#Attribute"},{"doc":"sprocket/html/attributes","title":"accept","content":"pub fn accept(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.accept\nsprocket/html/attributes accept","url":"sprocket/html/attributes.html#accept"},{"doc":"sprocket/html/attributes","title":"accept_charset","content":"pub fn accept_charset(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.accept_charset\nsprocket/html/attributes accept_charset","url":"sprocket/html/attributes.html#accept_charset"},{"doc":"sprocket/html/attributes","title":"action","content":"pub fn action(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.action\nsprocket/html/attributes action","url":"sprocket/html/attributes.html#action"},{"doc":"sprocket/html/attributes","title":"alt","content":"pub fn alt(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.alt\nsprocket/html/attributes alt","url":"sprocket/html/attributes.html#alt"},{"doc":"sprocket/html/attributes","title":"async","content":"pub fn async() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.async\nsprocket/html/attributes async","url":"sprocket/html/attributes.html#async"},{"doc":"sprocket/html/attributes","title":"attribute","content":"pub fn attribute(name: String, value: a) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.attribute\nsprocket/html/attributes attribute","url":"sprocket/html/attributes.html#attribute"},{"doc":"sprocket/html/attributes","title":"autocapitalize","content":"pub fn autocapitalize(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.autocapitalize\nsprocket/html/attributes autocapitalize","url":"sprocket/html/attributes.html#autocapitalize"},{"doc":"sprocket/html/attributes","title":"autocomplete","content":"pub fn autocomplete(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.autocomplete\nsprocket/html/attributes autocomplete","url":"sprocket/html/attributes.html#autocomplete"},{"doc":"sprocket/html/attributes","title":"autofocus","content":"pub fn autofocus() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.autofocus\nsprocket/html/attributes autofocus","url":"sprocket/html/attributes.html#autofocus"},{"doc":"sprocket/html/attributes","title":"autoplay","content":"pub fn autoplay() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.autoplay\nsprocket/html/attributes autoplay","url":"sprocket/html/attributes.html#autoplay"},{"doc":"sprocket/html/attributes","title":"capture","content":"pub fn capture(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.capture\nsprocket/html/attributes capture","url":"sprocket/html/attributes.html#capture"},{"doc":"sprocket/html/attributes","title":"charset","content":"pub fn charset(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.charset\nsprocket/html/attributes charset","url":"sprocket/html/attributes.html#charset"},{"doc":"sprocket/html/attributes","title":"checked","content":"pub fn checked() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.checked\nsprocket/html/attributes checked","url":"sprocket/html/attributes.html#checked"},{"doc":"sprocket/html/attributes","title":"cite","content":"pub fn cite(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.cite\nsprocket/html/attributes cite","url":"sprocket/html/attributes.html#cite"},{"doc":"sprocket/html/attributes","title":"class","content":"pub fn class(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.class\nsprocket/html/attributes class","url":"sprocket/html/attributes.html#class"},{"doc":"sprocket/html/attributes","title":"classes","content":"pub fn classes(value: List(Option(String))) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.classes\nsprocket/html/attributes classes","url":"sprocket/html/attributes.html#classes"},{"doc":"sprocket/html/attributes","title":"content","content":"pub fn content(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.content\nsprocket/html/attributes content","url":"sprocket/html/attributes.html#content"},{"doc":"sprocket/html/attributes","title":"contenteditable","content":"pub fn contenteditable() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.contenteditable\nsprocket/html/attributes contenteditable","url":"sprocket/html/attributes.html#contenteditable"},{"doc":"sprocket/html/attributes","title":"crossorigin","content":"pub fn crossorigin(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.crossorigin\nsprocket/html/attributes crossorigin","url":"sprocket/html/attributes.html#crossorigin"},{"doc":"sprocket/html/attributes","title":"defer","content":"pub fn defer() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.defer\nsprocket/html/attributes defer","url":"sprocket/html/attributes.html#defer"},{"doc":"sprocket/html/attributes","title":"disabled","content":"pub fn disabled() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.disabled\nsprocket/html/attributes disabled","url":"sprocket/html/attributes.html#disabled"},{"doc":"sprocket/html/attributes","title":"draggable","content":"pub fn draggable() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.draggable\nsprocket/html/attributes draggable","url":"sprocket/html/attributes.html#draggable"},{"doc":"sprocket/html/attributes","title":"event","content":"pub fn event(name: String, identifiable_cb: IdentifiableCallback) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.event\nsprocket/html/attributes event","url":"sprocket/html/attributes.html#event"},{"doc":"sprocket/html/attributes","title":"for","content":"pub fn for(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.for\nsprocket/html/attributes for","url":"sprocket/html/attributes.html#for"},{"doc":"sprocket/html/attributes","title":"formaction","content":"pub fn formaction(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.formaction\nsprocket/html/attributes formaction","url":"sprocket/html/attributes.html#formaction"},{"doc":"sprocket/html/attributes","title":"height","content":"pub fn height(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.height\nsprocket/html/attributes height","url":"sprocket/html/attributes.html#height"},{"doc":"sprocket/html/attributes","title":"href","content":"pub fn href(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.href\nsprocket/html/attributes href","url":"sprocket/html/attributes.html#href"},{"doc":"sprocket/html/attributes","title":"http_equiv","content":"pub fn http_equiv(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.http_equiv\nsprocket/html/attributes http_equiv","url":"sprocket/html/attributes.html#http_equiv"},{"doc":"sprocket/html/attributes","title":"id","content":"pub fn id(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.id\nsprocket/html/attributes id","url":"sprocket/html/attributes.html#id"},{"doc":"sprocket/html/attributes","title":"input_type","content":"pub fn input_type(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.input_type\nsprocket/html/attributes input_type","url":"sprocket/html/attributes.html#input_type"},{"doc":"sprocket/html/attributes","title":"integrity","content":"pub fn integrity(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.integrity\nsprocket/html/attributes integrity","url":"sprocket/html/attributes.html#integrity"},{"doc":"sprocket/html/attributes","title":"lang","content":"pub fn lang(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.lang\nsprocket/html/attributes lang","url":"sprocket/html/attributes.html#lang"},{"doc":"sprocket/html/attributes","title":"loop","content":"pub fn loop() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.loop\nsprocket/html/attributes loop","url":"sprocket/html/attributes.html#loop"},{"doc":"sprocket/html/attributes","title":"media","content":"pub fn media(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.media\nsprocket/html/attributes media","url":"sprocket/html/attributes.html#media"},{"doc":"sprocket/html/attributes","title":"method","content":"pub fn method(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.method\nsprocket/html/attributes method","url":"sprocket/html/attributes.html#method"},{"doc":"sprocket/html/attributes","title":"name","content":"pub fn name(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.name\nsprocket/html/attributes name","url":"sprocket/html/attributes.html#name"},{"doc":"sprocket/html/attributes","title":"on_change","content":"pub fn on_change(identifiable_cb: IdentifiableCallback) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.on_change\nsprocket/html/attributes on_change","url":"sprocket/html/attributes.html#on_change"},{"doc":"sprocket/html/attributes","title":"on_click","content":"pub fn on_click(identifiable_cb: IdentifiableCallback) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.on_click\nsprocket/html/attributes on_click","url":"sprocket/html/attributes.html#on_click"},{"doc":"sprocket/html/attributes","title":"on_doubleclick","content":"pub fn on_doubleclick(identifiable_cb: IdentifiableCallback) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.on_doubleclick\nsprocket/html/attributes on_doubleclick","url":"sprocket/html/attributes.html#on_doubleclick"},{"doc":"sprocket/html/attributes","title":"on_input","content":"pub fn on_input(identifiable_cb: IdentifiableCallback) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.on_input\nsprocket/html/attributes on_input","url":"sprocket/html/attributes.html#on_input"},{"doc":"sprocket/html/attributes","title":"placeholder","content":"pub fn placeholder(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.placeholder\nsprocket/html/attributes placeholder","url":"sprocket/html/attributes.html#placeholder"},{"doc":"sprocket/html/attributes","title":"preload","content":"pub fn preload() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.preload\nsprocket/html/attributes preload","url":"sprocket/html/attributes.html#preload"},{"doc":"sprocket/html/attributes","title":"property","content":"pub fn property(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.property\nsprocket/html/attributes property","url":"sprocket/html/attributes.html#property"},{"doc":"sprocket/html/attributes","title":"readonly","content":"pub fn readonly() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.readonly\nsprocket/html/attributes readonly","url":"sprocket/html/attributes.html#readonly"},{"doc":"sprocket/html/attributes","title":"referrerpolicy","content":"pub fn referrerpolicy(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.referrerpolicy\nsprocket/html/attributes referrerpolicy","url":"sprocket/html/attributes.html#referrerpolicy"},{"doc":"sprocket/html/attributes","title":"rel","content":"pub fn rel(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.rel\nsprocket/html/attributes rel","url":"sprocket/html/attributes.html#rel"},{"doc":"sprocket/html/attributes","title":"role","content":"pub fn role(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.role\nsprocket/html/attributes role","url":"sprocket/html/attributes.html#role"},{"doc":"sprocket/html/attributes","title":"selected","content":"pub fn selected() -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.selected\nsprocket/html/attributes selected","url":"sprocket/html/attributes.html#selected"},{"doc":"sprocket/html/attributes","title":"src","content":"pub fn src(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.src\nsprocket/html/attributes src","url":"sprocket/html/attributes.html#src"},{"doc":"sprocket/html/attributes","title":"style","content":"pub fn style(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.style\nsprocket/html/attributes style","url":"sprocket/html/attributes.html#style"},{"doc":"sprocket/html/attributes","title":"tabindex","content":"pub fn tabindex(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.tabindex\nsprocket/html/attributes tabindex","url":"sprocket/html/attributes.html#tabindex"},{"doc":"sprocket/html/attributes","title":"target","content":"pub fn target(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.target\nsprocket/html/attributes target","url":"sprocket/html/attributes.html#target"},{"doc":"sprocket/html/attributes","title":"title","content":"pub fn title(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.title\nsprocket/html/attributes title","url":"sprocket/html/attributes.html#title"},{"doc":"sprocket/html/attributes","title":"value","content":"pub fn value(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.value\nsprocket/html/attributes value","url":"sprocket/html/attributes.html#value"},{"doc":"sprocket/html/attributes","title":"width","content":"pub fn width(value: String) -&gt; Attribute\n\nSynonyms:\nsprocket/html/attributes.width\nsprocket/html/attributes width","url":"sprocket/html/attributes.html#width"},{"doc":"sprocket/html/attributes","title":"sprocket/html/attributes","content":"","url":"sprocket/html/attributes.html"},{"doc":"sprocket/context","title":"ComponentHooks","content":"pub type ComponentHooks =\n  OrderedMap(Int, Hook)\n\n\nSynonyms:\nsprocket/context.ComponentHooks\nsprocket/context ComponentHooks","url":"sprocket/context.html#ComponentHooks"},{"doc":"sprocket/context","title":"ComponentWip","content":"pub type ComponentWip {\n  ComponentWip(\n    hooks: ComponentHooks,\n    index: Int,\n    is_first_render: Bool,\n  )\n}\n\nComponentWip(\n  hooks: ComponentHooks,\n  index: Int,\n  is_first_render: Bool,\n)\n\n\nSynonyms:\nsprocket/context.ComponentWip\nsprocket/context ComponentWip","url":"sprocket/context.html#ComponentWip"},{"doc":"sprocket/context","title":"Context","content":"pub type Context {\n  Context(\n    wip: ComponentWip,\n    handlers: List(EventHandler),\n    ws: Option(WebSocket),\n    render_update: fn() -&gt; Nil,\n    update_hook: fn(Unique, fn(Hook) -&gt; Hook) -&gt; Nil,\n  )\n}\n\nContext(\n  wip: ComponentWip,\n  handlers: List(EventHandler),\n  ws: Option(WebSocket),\n  render_update: fn() -&gt; Nil,\n  update_hook: fn(Unique, fn(Hook) -&gt; Hook) -&gt; Nil,\n)\n\n\nSynonyms:\nsprocket/context.Context\nsprocket/context Context","url":"sprocket/context.html#Context"},{"doc":"sprocket/context","title":"EventHandler","content":"pub type EventHandler {\n  EventHandler(id: Unique, handler: CallbackFn)\n}\n\nEventHandler(id: Unique, handler: CallbackFn)\n\n\nSynonyms:\nsprocket/context.EventHandler\nsprocket/context EventHandler","url":"sprocket/context.html#EventHandler"},{"doc":"sprocket/context","title":"Updater","content":"pub type Updater(r) {\n  Updater(send: fn(r) -&gt; Result(Nil, Nil))\n}\n\nUpdater(send: fn(r) -&gt; Result(Nil, Nil))\n\n\nSynonyms:\nsprocket/context.Updater\nsprocket/context Updater","url":"sprocket/context.html#Updater"},{"doc":"sprocket/context","title":"WebSocket","content":"pub type WebSocket =\n  Subject(HandlerMessage)\n\n\nSynonyms:\nsprocket/context.WebSocket\nsprocket/context WebSocket","url":"sprocket/context.html#WebSocket"},{"doc":"sprocket/context","title":"fetch_or_init_hook","content":"pub fn fetch_or_init_hook(ctx: Context, init: fn() -&gt; Hook) -&gt; #(\n  Context,\n  Hook,\n  Int,\n)\n\nSynonyms:\nsprocket/context.fetch_or_init_hook\nsprocket/context fetch_or_init_hook","url":"sprocket/context.html#fetch_or_init_hook"},{"doc":"sprocket/context","title":"get_event_handler","content":"pub fn get_event_handler(ctx: Context, id: Unique) -&gt; #(\n  Context,\n  Result(EventHandler, Nil),\n)\n\nSynonyms:\nsprocket/context.get_event_handler\nsprocket/context get_event_handler","url":"sprocket/context.html#get_event_handler"},{"doc":"sprocket/context","title":"new","content":"pub fn new(ws: Option(Subject(HandlerMessage))) -&gt; Context\n\nSynonyms:\nsprocket/context.new\nsprocket/context new","url":"sprocket/context.html#new"},{"doc":"sprocket/context","title":"push_event_handler","content":"pub fn push_event_handler(ctx: Context, identifiable_cb: IdentifiableCallback) -&gt; #(\n  Context,\n  Unique,\n)\n\nSynonyms:\nsprocket/context.push_event_handler\nsprocket/context push_event_handler","url":"sprocket/context.html#push_event_handler"},{"doc":"sprocket/context","title":"reset_for_render","content":"pub fn reset_for_render(ctx: Context) -&gt; Context\n\nSynonyms:\nsprocket/context.reset_for_render\nsprocket/context reset_for_render","url":"sprocket/context.html#reset_for_render"},{"doc":"sprocket/context","title":"update_hook","content":"pub fn update_hook(ctx: Context, hook: Hook, index: Int) -&gt; Context\n\nSynonyms:\nsprocket/context.update_hook\nsprocket/context update_hook","url":"sprocket/context.html#update_hook"},{"doc":"sprocket/context","title":"sprocket/context","content":"","url":"sprocket/context.html"},{"doc":"sprocket/element","title":"AbstractFunctionalComponent","content":"pub type AbstractFunctionalComponent =\n  fn(Context, Dynamic) -&gt; #(Context, List(Element))\n\n\nSynonyms:\nsprocket/element.AbstractFunctionalComponent\nsprocket/element AbstractFunctionalComponent","url":"sprocket/element.html#AbstractFunctionalComponent"},{"doc":"sprocket/element","title":"Element","content":"pub type Element {\n  Element(\n    tag: String,\n    attrs: List(Attribute),\n    children: List(Element),\n  )\n  Component(\n    component: FunctionalComponent(Dynamic),\n    props: Dynamic,\n  )\n  Debug(id: String, meta: Option(Dynamic), element: Element)\n  Keyed(key: String, element: Element)\n  IgnoreUpdate(element: Element)\n  SafeHtml(html: String)\n  Raw(text: String)\n}\n\nElement(\n  tag: String,\n  attrs: List(Attribute),\n  children: List(Element),\n)\n\n\nComponent(\n  component: FunctionalComponent(Dynamic),\n  props: Dynamic,\n)\n\n\nDebug(id: String, meta: Option(Dynamic), element: Element)\n\n\nKeyed(key: String, element: Element)\n\n\nIgnoreUpdate(element: Element)\n\n\nSafeHtml(html: String)\n\n\nRaw(text: String)\n\n\nSynonyms:\nsprocket/element.Element\nsprocket/element Element","url":"sprocket/element.html#Element"},{"doc":"sprocket/element","title":"FunctionalComponent","content":"pub type FunctionalComponent(p) =\n  fn(Context, p) -&gt; #(Context, List(Element))\n\n\nSynonyms:\nsprocket/element.FunctionalComponent\nsprocket/element FunctionalComponent","url":"sprocket/element.html#FunctionalComponent"},{"doc":"sprocket/element","title":"sprocket/element","content":"","url":"sprocket/element.html"},{"doc":"sprocket/render","title":"RenderResult","content":"pub type RenderResult(a) {\n  RenderResult(ctx: Context, rendered: a)\n}\n\nRenderResult(ctx: Context, rendered: a)\n\n\nSynonyms:\nsprocket/render.RenderResult\nsprocket/render RenderResult","url":"sprocket/render.html#RenderResult"},{"doc":"sprocket/render","title":"RenderedAttribute","content":"pub type RenderedAttribute {\n  RenderedAttribute(name: String, value: String)\n  RenderedEventHandler(kind: String, id: String)\n}\n\nRenderedAttribute(name: String, value: String)\n\n\nRenderedEventHandler(kind: String, id: String)\n\n\nSynonyms:\nsprocket/render.RenderedAttribute\nsprocket/render RenderedAttribute","url":"sprocket/render.html#RenderedAttribute"},{"doc":"sprocket/render","title":"RenderedElement","content":"pub type RenderedElement {\n  RenderedElement(\n    tag: String,\n    key: Option(String),\n    attrs: List(RenderedAttribute),\n    children: List(RenderedElement),\n  )\n  RenderedComponent(\n    fc: AbstractFunctionalComponent,\n    key: Option(String),\n    props: Dynamic,\n    hooks: ComponentHooks,\n    children: List(RenderedElement),\n  )\n  RenderedText(text: String)\n}\n\nRenderedElement(\n  tag: String,\n  key: Option(String),\n  attrs: List(RenderedAttribute),\n  children: List(RenderedElement),\n)\n\n\nRenderedComponent(\n  fc: AbstractFunctionalComponent,\n  key: Option(String),\n  props: Dynamic,\n  hooks: ComponentHooks,\n  children: List(RenderedElement),\n)\n\n\nRenderedText(text: String)\n\n\nSynonyms:\nsprocket/render.RenderedElement\nsprocket/render RenderedElement","url":"sprocket/render.html#RenderedElement"},{"doc":"sprocket/render","title":"Renderer","content":"pub type Renderer(result) {\n  Renderer(render: fn(RenderedElement) -&gt; result)\n}\n\nRenderer(render: fn(RenderedElement) -&gt; result)\n\n\nSynonyms:\nsprocket/render.Renderer\nsprocket/render Renderer","url":"sprocket/render.html#Renderer"},{"doc":"sprocket/render","title":"append_attribute","content":"pub fn append_attribute(el: RenderedElement, attr: RenderedAttribute) -&gt; RenderedElement\n\nSynonyms:\nsprocket/render.append_attribute\nsprocket/render append_attribute","url":"sprocket/render.html#append_attribute"},{"doc":"sprocket/render","title":"find","content":"pub fn find(el: RenderedElement, matches: fn(RenderedElement) -&gt;\n    Bool) -&gt; Result(RenderedElement, Nil)\n\nSynonyms:\nsprocket/render.find\nsprocket/render find","url":"sprocket/render.html#find"},{"doc":"sprocket/render","title":"live_render","content":"pub fn live_render(ctx: Context, el: Element, key: Option(String), prev: Option(\n    RenderedElement,\n  )) -&gt; RenderResult(RenderedElement)\n\nSynonyms:\nsprocket/render.live_render\nsprocket/render live_render","url":"sprocket/render.html#live_render"},{"doc":"sprocket/render","title":"render","content":"pub fn render(el: Element, renderer: Renderer(a)) -&gt; a\n\nSynonyms:\nsprocket/render.render\nsprocket/render render","url":"sprocket/render.html#render"},{"doc":"sprocket/render","title":"render_element","content":"pub fn render_element(el: Element) -&gt; RenderedElement\n Renders the given element into a stateless RenderedElement tree.\nSynonyms:\nsprocket/render.render_element\nsprocket/render render_element","url":"sprocket/render.html#render_element"},{"doc":"sprocket/render","title":"traverse","content":"pub fn traverse(el: RenderedElement, updater: fn(RenderedElement) -&gt;\n    RenderedElement) -&gt; RenderedElement\n\nSynonyms:\nsprocket/render.traverse\nsprocket/render traverse","url":"sprocket/render.html#traverse"},{"doc":"sprocket/render","title":"sprocket/render","content":"","url":"sprocket/render.html"},{"doc":"sprocket/component","title":"component","content":"pub fn component(c: fn(Context, a) -&gt; #(Context, List(Element)), props: a) -&gt; Element\n\nSynonyms:\nsprocket/component.component\nsprocket/component component","url":"sprocket/component.html#component"},{"doc":"sprocket/component","title":"render","content":"pub fn render(ctx: Context, elements: List(Element)) -&gt; #(\n  Context,\n  List(Element),\n)\n\nSynonyms:\nsprocket/component.render\nsprocket/component render","url":"sprocket/component.html#render"},{"doc":"sprocket/component","title":"sprocket/component","content":"","url":"sprocket/component.html"},{"doc":"sprocket/hooks/reducer","title":"State","content":"pub type State(model, msg) {\n  State(m: model, d: Updater(msg))\n}\n\nState(m: model, d: Updater(msg))\n\n\nSynonyms:\nsprocket/hooks/reducer.State\nsprocket/hooks/reducer State","url":"sprocket/hooks/reducer.html#State"},{"doc":"sprocket/hooks/reducer","title":"Updater","content":"pub type Updater(msg) =\n  fn(msg) -&gt; Nil\n\n\nSynonyms:\nsprocket/hooks/reducer.Updater\nsprocket/hooks/reducer Updater","url":"sprocket/hooks/reducer.html#Updater"},{"doc":"sprocket/hooks/reducer","title":"reducer","content":"pub fn reducer(ctx: Context, initial: a, reducer: fn(a, b) -&gt; a, cb: fn(\n    Context,\n    State(a, b),\n  ) -&gt; #(Context, List(Element))) -&gt; #(Context, List(Element))\n\nSynonyms:\nsprocket/hooks/reducer.reducer\nsprocket/hooks/reducer reducer","url":"sprocket/hooks/reducer.html#reducer"},{"doc":"sprocket/hooks/reducer","title":"sprocket/hooks/reducer","content":"","url":"sprocket/hooks/reducer.html"},{"doc":"sprocket/hooks/callback","title":"callback","content":"pub fn callback(ctx: Context, callback_fn: CallbackFn, trigger: HookTrigger, cb: fn(\n    Context,\n    IdentifiableCallback,\n  ) -&gt; #(a, List(Element))) -&gt; #(a, List(Element))\n\nSynonyms:\nsprocket/hooks/callback.callback\nsprocket/hooks/callback callback","url":"sprocket/hooks/callback.html#callback"},{"doc":"sprocket/hooks/callback","title":"sprocket/hooks/callback","content":"","url":"sprocket/hooks/callback.html"},{"doc":"sprocket/html","title":"a","content":"pub fn a(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;a&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/a)\nSynonyms:\nsprocket/html.a\nsprocket/html a","url":"sprocket/html.html#a"},{"doc":"sprocket/html","title":"a_text","content":"pub fn a_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.a(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.a_text\nsprocket/html a_text","url":"sprocket/html.html#a_text"},{"doc":"sprocket/html","title":"abbr","content":"pub fn abbr(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;abbr&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/abbr)\nSynonyms:\nsprocket/html.abbr\nsprocket/html abbr","url":"sprocket/html.html#abbr"},{"doc":"sprocket/html","title":"address","content":"pub fn address(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;address&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/address)\nSynonyms:\nsprocket/html.address\nsprocket/html address","url":"sprocket/html.html#address"},{"doc":"sprocket/html","title":"area","content":"pub fn area(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;area /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/area)\nSynonyms:\nsprocket/html.area\nsprocket/html area","url":"sprocket/html.html#area"},{"doc":"sprocket/html","title":"article","content":"pub fn article(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;article&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/article)\nSynonyms:\nsprocket/html.article\nsprocket/html article","url":"sprocket/html.html#article"},{"doc":"sprocket/html","title":"article_text","content":"pub fn article_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.article(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.article_text\nsprocket/html article_text","url":"sprocket/html.html#article_text"},{"doc":"sprocket/html","title":"aside","content":"pub fn aside(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;aside&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/aside)\nSynonyms:\nsprocket/html.aside\nsprocket/html aside","url":"sprocket/html.html#aside"},{"doc":"sprocket/html","title":"aside_text","content":"pub fn aside_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.aside(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.aside_text\nsprocket/html aside_text","url":"sprocket/html.html#aside_text"},{"doc":"sprocket/html","title":"audio","content":"pub fn audio(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;audio&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/audio)\nSynonyms:\nsprocket/html.audio\nsprocket/html audio","url":"sprocket/html.html#audio"},{"doc":"sprocket/html","title":"audio_text","content":"pub fn audio_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.audio(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.audio_text\nsprocket/html audio_text","url":"sprocket/html.html#audio_text"},{"doc":"sprocket/html","title":"b","content":"pub fn b(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;b&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/b)\nSynonyms:\nsprocket/html.b\nsprocket/html b","url":"sprocket/html.html#b"},{"doc":"sprocket/html","title":"b_text","content":"pub fn b_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.b(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.b_text\nsprocket/html b_text","url":"sprocket/html.html#b_text"},{"doc":"sprocket/html","title":"base","content":"pub fn base(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;base /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/base)\nSynonyms:\nsprocket/html.base\nsprocket/html base","url":"sprocket/html.html#base"},{"doc":"sprocket/html","title":"bdi","content":"pub fn bdi(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;bdi&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/bdi)\nSynonyms:\nsprocket/html.bdi\nsprocket/html bdi","url":"sprocket/html.html#bdi"},{"doc":"sprocket/html","title":"bdi_text","content":"pub fn bdi_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.bdi(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.bdi_text\nsprocket/html bdi_text","url":"sprocket/html.html#bdi_text"},{"doc":"sprocket/html","title":"bdo","content":"pub fn bdo(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;bdo&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/bdo)\nSynonyms:\nsprocket/html.bdo\nsprocket/html bdo","url":"sprocket/html.html#bdo"},{"doc":"sprocket/html","title":"bdo_text","content":"pub fn bdo_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.bdo(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.bdo_text\nsprocket/html bdo_text","url":"sprocket/html.html#bdo_text"},{"doc":"sprocket/html","title":"blockquote","content":"pub fn blockquote(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;blockquote&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/blockquote)\nSynonyms:\nsprocket/html.blockquote\nsprocket/html blockquote","url":"sprocket/html.html#blockquote"},{"doc":"sprocket/html","title":"blockquote_text","content":"pub fn blockquote_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.blockquote(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.blockquote_text\nsprocket/html blockquote_text","url":"sprocket/html.html#blockquote_text"},{"doc":"sprocket/html","title":"body","content":"pub fn body(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;body&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/body)\nSynonyms:\nsprocket/html.body\nsprocket/html body","url":"sprocket/html.html#body"},{"doc":"sprocket/html","title":"br","content":"pub fn br(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;br /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/br)\nSynonyms:\nsprocket/html.br\nsprocket/html br","url":"sprocket/html.html#br"},{"doc":"sprocket/html","title":"button","content":"pub fn button(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;button&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/button)\nSynonyms:\nsprocket/html.button\nsprocket/html button","url":"sprocket/html.html#button"},{"doc":"sprocket/html","title":"button_text","content":"pub fn button_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.button(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.button_text\nsprocket/html button_text","url":"sprocket/html.html#button_text"},{"doc":"sprocket/html","title":"canvas","content":"pub fn canvas(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;canvas&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/canvas)\nSynonyms:\nsprocket/html.canvas\nsprocket/html canvas","url":"sprocket/html.html#canvas"},{"doc":"sprocket/html","title":"canvas_text","content":"pub fn canvas_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.canvas(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.canvas_text\nsprocket/html canvas_text","url":"sprocket/html.html#canvas_text"},{"doc":"sprocket/html","title":"caption","content":"pub fn caption(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;caption&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/caption)\nSynonyms:\nsprocket/html.caption\nsprocket/html caption","url":"sprocket/html.html#caption"},{"doc":"sprocket/html","title":"caption_text","content":"pub fn caption_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.caption(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.caption_text\nsprocket/html caption_text","url":"sprocket/html.html#caption_text"},{"doc":"sprocket/html","title":"cite","content":"pub fn cite(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;cite&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/cite)\nSynonyms:\nsprocket/html.cite\nsprocket/html cite","url":"sprocket/html.html#cite"},{"doc":"sprocket/html","title":"cite_text","content":"pub fn cite_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.cite(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.cite_text\nsprocket/html cite_text","url":"sprocket/html.html#cite_text"},{"doc":"sprocket/html","title":"code","content":"pub fn code(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;code&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/code)\nSynonyms:\nsprocket/html.code\nsprocket/html code","url":"sprocket/html.html#code"},{"doc":"sprocket/html","title":"code_text","content":"pub fn code_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.code(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.code_text\nsprocket/html code_text","url":"sprocket/html.html#code_text"},{"doc":"sprocket/html","title":"col","content":"pub fn col(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;col&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/col)\nSynonyms:\nsprocket/html.col\nsprocket/html col","url":"sprocket/html.html#col"},{"doc":"sprocket/html","title":"col_text","content":"pub fn col_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.col(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.col_text\nsprocket/html col_text","url":"sprocket/html.html#col_text"},{"doc":"sprocket/html","title":"colgroup","content":"pub fn colgroup(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;colgroup&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/colgroup)\nSynonyms:\nsprocket/html.colgroup\nsprocket/html colgroup","url":"sprocket/html.html#colgroup"},{"doc":"sprocket/html","title":"colgroup_text","content":"pub fn colgroup_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.colgroup(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.colgroup_text\nsprocket/html colgroup_text","url":"sprocket/html.html#colgroup_text"},{"doc":"sprocket/html","title":"dangerous_raw_html","content":"pub fn dangerous_raw_html(html: String) -&gt; Element\n\nSynonyms:\nsprocket/html.dangerous_raw_html\nsprocket/html dangerous_raw_html","url":"sprocket/html.html#dangerous_raw_html"},{"doc":"sprocket/html","title":"data","content":"pub fn data(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;data&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/data)\nSynonyms:\nsprocket/html.data\nsprocket/html data","url":"sprocket/html.html#data"},{"doc":"sprocket/html","title":"data_text","content":"pub fn data_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.data(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.data_text\nsprocket/html data_text","url":"sprocket/html.html#data_text"},{"doc":"sprocket/html","title":"datalist","content":"pub fn datalist(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;datalist&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/datalist)\nSynonyms:\nsprocket/html.datalist\nsprocket/html datalist","url":"sprocket/html.html#datalist"},{"doc":"sprocket/html","title":"datalist_text","content":"pub fn datalist_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.datalist(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.datalist_text\nsprocket/html datalist_text","url":"sprocket/html.html#datalist_text"},{"doc":"sprocket/html","title":"dd","content":"pub fn dd(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;dd&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/dd)\nSynonyms:\nsprocket/html.dd\nsprocket/html dd","url":"sprocket/html.html#dd"},{"doc":"sprocket/html","title":"dd_text","content":"pub fn dd_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.dd(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.dd_text\nsprocket/html dd_text","url":"sprocket/html.html#dd_text"},{"doc":"sprocket/html","title":"debug","content":"pub fn debug(id: String, meta: Option(Dynamic), element: Element) -&gt; Element\n\nSynonyms:\nsprocket/html.debug\nsprocket/html debug","url":"sprocket/html.html#debug"},{"doc":"sprocket/html","title":"del","content":"pub fn del(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;del&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/del)\nSynonyms:\nsprocket/html.del\nsprocket/html del","url":"sprocket/html.html#del"},{"doc":"sprocket/html","title":"del_text","content":"pub fn del_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.del(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.del_text\nsprocket/html del_text","url":"sprocket/html.html#del_text"},{"doc":"sprocket/html","title":"details","content":"pub fn details(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;details&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/details)\nSynonyms:\nsprocket/html.details\nsprocket/html details","url":"sprocket/html.html#details"},{"doc":"sprocket/html","title":"details_text","content":"pub fn details_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.details(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.details_text\nsprocket/html details_text","url":"sprocket/html.html#details_text"},{"doc":"sprocket/html","title":"dfn","content":"pub fn dfn(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;dfn&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/dfn)\nSynonyms:\nsprocket/html.dfn\nsprocket/html dfn","url":"sprocket/html.html#dfn"},{"doc":"sprocket/html","title":"dfn_text","content":"pub fn dfn_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.dfn(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.dfn_text\nsprocket/html dfn_text","url":"sprocket/html.html#dfn_text"},{"doc":"sprocket/html","title":"dialog","content":"pub fn dialog(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;dialog&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/dialog)\nSynonyms:\nsprocket/html.dialog\nsprocket/html dialog","url":"sprocket/html.html#dialog"},{"doc":"sprocket/html","title":"dialog_text","content":"pub fn dialog_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.dialog(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.dialog_text\nsprocket/html dialog_text","url":"sprocket/html.html#dialog_text"},{"doc":"sprocket/html","title":"div","content":"pub fn div(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;div&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/div)\nSynonyms:\nsprocket/html.div\nsprocket/html div","url":"sprocket/html.html#div"},{"doc":"sprocket/html","title":"div_text","content":"pub fn div_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.div(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.div_text\nsprocket/html div_text","url":"sprocket/html.html#div_text"},{"doc":"sprocket/html","title":"dl","content":"pub fn dl(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;dl&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/dl)\nSynonyms:\nsprocket/html.dl\nsprocket/html dl","url":"sprocket/html.html#dl"},{"doc":"sprocket/html","title":"dl_text","content":"pub fn dl_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.dl(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.dl_text\nsprocket/html dl_text","url":"sprocket/html.html#dl_text"},{"doc":"sprocket/html","title":"dt","content":"pub fn dt(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;dt&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/dt)\nSynonyms:\nsprocket/html.dt\nsprocket/html dt","url":"sprocket/html.html#dt"},{"doc":"sprocket/html","title":"dt_text","content":"pub fn dt_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.dt(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.dt_text\nsprocket/html dt_text","url":"sprocket/html.html#dt_text"},{"doc":"sprocket/html","title":"el","content":"pub fn el(tag: String, attrs: List(Attribute), children: List(\n    Element,\n  )) -&gt; Element\n\nSynonyms:\nsprocket/html.el\nsprocket/html el","url":"sprocket/html.html#el"},{"doc":"sprocket/html","title":"em","content":"pub fn em(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;em&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/em)\nSynonyms:\nsprocket/html.em\nsprocket/html em","url":"sprocket/html.html#em"},{"doc":"sprocket/html","title":"em_text","content":"pub fn em_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.em(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.em_text\nsprocket/html em_text","url":"sprocket/html.html#em_text"},{"doc":"sprocket/html","title":"embed","content":"pub fn embed(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;embed&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/embed)\nSynonyms:\nsprocket/html.embed\nsprocket/html embed","url":"sprocket/html.html#embed"},{"doc":"sprocket/html","title":"embed_text","content":"pub fn embed_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.embed(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.embed_text\nsprocket/html embed_text","url":"sprocket/html.html#embed_text"},{"doc":"sprocket/html","title":"fieldset","content":"pub fn fieldset(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;fieldset&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/fieldset)\nSynonyms:\nsprocket/html.fieldset\nsprocket/html fieldset","url":"sprocket/html.html#fieldset"},{"doc":"sprocket/html","title":"fieldset_text","content":"pub fn fieldset_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.fieldset(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.fieldset_text\nsprocket/html fieldset_text","url":"sprocket/html.html#fieldset_text"},{"doc":"sprocket/html","title":"figcaption","content":"pub fn figcaption(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;figcaption&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/figcaption)\nSynonyms:\nsprocket/html.figcaption\nsprocket/html figcaption","url":"sprocket/html.html#figcaption"},{"doc":"sprocket/html","title":"figcaption_text","content":"pub fn figcaption_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.figcaption(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.figcaption_text\nsprocket/html figcaption_text","url":"sprocket/html.html#figcaption_text"},{"doc":"sprocket/html","title":"figure","content":"pub fn figure(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;figure&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/figure)\nSynonyms:\nsprocket/html.figure\nsprocket/html figure","url":"sprocket/html.html#figure"},{"doc":"sprocket/html","title":"figure_text","content":"pub fn figure_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.figure(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.figure_text\nsprocket/html figure_text","url":"sprocket/html.html#figure_text"},{"doc":"sprocket/html","title":"footer","content":"pub fn footer(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;footer&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/footer)\nSynonyms:\nsprocket/html.footer\nsprocket/html footer","url":"sprocket/html.html#footer"},{"doc":"sprocket/html","title":"footer_text","content":"pub fn footer_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.footer(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.footer_text\nsprocket/html footer_text","url":"sprocket/html.html#footer_text"},{"doc":"sprocket/html","title":"form","content":"pub fn form(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;form&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/form)\nSynonyms:\nsprocket/html.form\nsprocket/html form","url":"sprocket/html.html#form"},{"doc":"sprocket/html","title":"form_text","content":"pub fn form_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.form(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.form_text\nsprocket/html form_text","url":"sprocket/html.html#form_text"},{"doc":"sprocket/html","title":"h1","content":"pub fn h1(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;h1&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/h1)\nSynonyms:\nsprocket/html.h1\nsprocket/html h1","url":"sprocket/html.html#h1"},{"doc":"sprocket/html","title":"h1_text","content":"pub fn h1_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.h1(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.h1_text\nsprocket/html h1_text","url":"sprocket/html.html#h1_text"},{"doc":"sprocket/html","title":"h2","content":"pub fn h2(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;h2&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/h2)\nSynonyms:\nsprocket/html.h2\nsprocket/html h2","url":"sprocket/html.html#h2"},{"doc":"sprocket/html","title":"h2_text","content":"pub fn h2_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.h2(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.h2_text\nsprocket/html h2_text","url":"sprocket/html.html#h2_text"},{"doc":"sprocket/html","title":"h3","content":"pub fn h3(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;h3&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/h3)\nSynonyms:\nsprocket/html.h3\nsprocket/html h3","url":"sprocket/html.html#h3"},{"doc":"sprocket/html","title":"h3_text","content":"pub fn h3_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.h3(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.h3_text\nsprocket/html h3_text","url":"sprocket/html.html#h3_text"},{"doc":"sprocket/html","title":"h4","content":"pub fn h4(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;h4&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/h4)\nSynonyms:\nsprocket/html.h4\nsprocket/html h4","url":"sprocket/html.html#h4"},{"doc":"sprocket/html","title":"h4_text","content":"pub fn h4_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.h4(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.h4_text\nsprocket/html h4_text","url":"sprocket/html.html#h4_text"},{"doc":"sprocket/html","title":"h5","content":"pub fn h5(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;h5&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/h5)\nSynonyms:\nsprocket/html.h5\nsprocket/html h5","url":"sprocket/html.html#h5"},{"doc":"sprocket/html","title":"h5_text","content":"pub fn h5_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.h5(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.h5_text\nsprocket/html h5_text","url":"sprocket/html.html#h5_text"},{"doc":"sprocket/html","title":"h6","content":"pub fn h6(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;h6&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/h6)\nSynonyms:\nsprocket/html.h6\nsprocket/html h6","url":"sprocket/html.html#h6"},{"doc":"sprocket/html","title":"h6_text","content":"pub fn h6_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.h6(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.h6_text\nsprocket/html h6_text","url":"sprocket/html.html#h6_text"},{"doc":"sprocket/html","title":"head","content":"pub fn head(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;head&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/head)\nSynonyms:\nsprocket/html.head\nsprocket/html head","url":"sprocket/html.html#head"},{"doc":"sprocket/html","title":"header","content":"pub fn header(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;header&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/header)\nSynonyms:\nsprocket/html.header\nsprocket/html header","url":"sprocket/html.html#header"},{"doc":"sprocket/html","title":"header_text","content":"pub fn header_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.header(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.header_text\nsprocket/html header_text","url":"sprocket/html.html#header_text"},{"doc":"sprocket/html","title":"hr","content":"pub fn hr(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;hr /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/hr)\nSynonyms:\nsprocket/html.hr\nsprocket/html hr","url":"sprocket/html.html#hr"},{"doc":"sprocket/html","title":"html","content":"pub fn html(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;html&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/html)\nSynonyms:\nsprocket/html.html\nsprocket/html html","url":"sprocket/html.html#html"},{"doc":"sprocket/html","title":"i","content":"pub fn i(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;i&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/i)\nSynonyms:\nsprocket/html.i\nsprocket/html i","url":"sprocket/html.html#i"},{"doc":"sprocket/html","title":"i_text","content":"pub fn i_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.i(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.i_text\nsprocket/html i_text","url":"sprocket/html.html#i_text"},{"doc":"sprocket/html","title":"iframe","content":"pub fn iframe(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;iframe&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/iframe)\nSynonyms:\nsprocket/html.iframe\nsprocket/html iframe","url":"sprocket/html.html#iframe"},{"doc":"sprocket/html","title":"iframe_text","content":"pub fn iframe_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.iframe(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.iframe_text\nsprocket/html iframe_text","url":"sprocket/html.html#iframe_text"},{"doc":"sprocket/html","title":"ignored","content":"pub fn ignored(element: Element) -&gt; Element\n\nSynonyms:\nsprocket/html.ignored\nsprocket/html ignored","url":"sprocket/html.html#ignored"},{"doc":"sprocket/html","title":"img","content":"pub fn img(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;img /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/img)\nSynonyms:\nsprocket/html.img\nsprocket/html img","url":"sprocket/html.html#img"},{"doc":"sprocket/html","title":"input","content":"pub fn input(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;input /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/input)\nSynonyms:\nsprocket/html.input\nsprocket/html input","url":"sprocket/html.html#input"},{"doc":"sprocket/html","title":"ins","content":"pub fn ins(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;ins&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/ins)\nSynonyms:\nsprocket/html.ins\nsprocket/html ins","url":"sprocket/html.html#ins"},{"doc":"sprocket/html","title":"ins_text","content":"pub fn ins_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.ins(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.ins_text\nsprocket/html ins_text","url":"sprocket/html.html#ins_text"},{"doc":"sprocket/html","title":"kbd","content":"pub fn kbd(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;kbd&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/kbd)\nSynonyms:\nsprocket/html.kbd\nsprocket/html kbd","url":"sprocket/html.html#kbd"},{"doc":"sprocket/html","title":"kbd_text","content":"pub fn kbd_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.kbd(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.kbd_text\nsprocket/html kbd_text","url":"sprocket/html.html#kbd_text"},{"doc":"sprocket/html","title":"keyed","content":"pub fn keyed(key: String, element: Element) -&gt; Element\n\nSynonyms:\nsprocket/html.keyed\nsprocket/html keyed","url":"sprocket/html.html#keyed"},{"doc":"sprocket/html","title":"label","content":"pub fn label(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;label&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/label)\nSynonyms:\nsprocket/html.label\nsprocket/html label","url":"sprocket/html.html#label"},{"doc":"sprocket/html","title":"label_text","content":"pub fn label_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.label(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.label_text\nsprocket/html label_text","url":"sprocket/html.html#label_text"},{"doc":"sprocket/html","title":"legend","content":"pub fn legend(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;legend&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/legend)\nSynonyms:\nsprocket/html.legend\nsprocket/html legend","url":"sprocket/html.html#legend"},{"doc":"sprocket/html","title":"legend_text","content":"pub fn legend_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.legend(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.legend_text\nsprocket/html legend_text","url":"sprocket/html.html#legend_text"},{"doc":"sprocket/html","title":"li","content":"pub fn li(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;li&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/li)\nSynonyms:\nsprocket/html.li\nsprocket/html li","url":"sprocket/html.html#li"},{"doc":"sprocket/html","title":"li_text","content":"pub fn li_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.li(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.li_text\nsprocket/html li_text","url":"sprocket/html.html#li_text"},{"doc":"sprocket/html","title":"link","content":"pub fn link(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;link /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/link)\nSynonyms:\nsprocket/html.link\nsprocket/html link","url":"sprocket/html.html#link"},{"doc":"sprocket/html","title":"main","content":"pub fn main(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;main&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/main)\nSynonyms:\nsprocket/html.main\nsprocket/html main","url":"sprocket/html.html#main"},{"doc":"sprocket/html","title":"main_text","content":"pub fn main_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.main(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.main_text\nsprocket/html main_text","url":"sprocket/html.html#main_text"},{"doc":"sprocket/html","title":"map","content":"pub fn map(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;map&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/map)\nSynonyms:\nsprocket/html.map\nsprocket/html map","url":"sprocket/html.html#map"},{"doc":"sprocket/html","title":"map_text","content":"pub fn map_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.map(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.map_text\nsprocket/html map_text","url":"sprocket/html.html#map_text"},{"doc":"sprocket/html","title":"mark","content":"pub fn mark(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;mark&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/mark)\nSynonyms:\nsprocket/html.mark\nsprocket/html mark","url":"sprocket/html.html#mark"},{"doc":"sprocket/html","title":"mark_text","content":"pub fn mark_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.mark(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.mark_text\nsprocket/html mark_text","url":"sprocket/html.html#mark_text"},{"doc":"sprocket/html","title":"math","content":"pub fn math(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;math&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/math)\nSynonyms:\nsprocket/html.math\nsprocket/html math","url":"sprocket/html.html#math"},{"doc":"sprocket/html","title":"math_text","content":"pub fn math_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.math(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.math_text\nsprocket/html math_text","url":"sprocket/html.html#math_text"},{"doc":"sprocket/html","title":"menu","content":"pub fn menu(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;menu&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/menu)\nSynonyms:\nsprocket/html.menu\nsprocket/html menu","url":"sprocket/html.html#menu"},{"doc":"sprocket/html","title":"menu_text","content":"pub fn menu_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.menu(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.menu_text\nsprocket/html menu_text","url":"sprocket/html.html#menu_text"},{"doc":"sprocket/html","title":"menuitem","content":"pub fn menuitem(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;menuitem&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/menuitem)\nSynonyms:\nsprocket/html.menuitem\nsprocket/html menuitem","url":"sprocket/html.html#menuitem"},{"doc":"sprocket/html","title":"menuitem_text","content":"pub fn menuitem_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.menuitem(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.menuitem_text\nsprocket/html menuitem_text","url":"sprocket/html.html#menuitem_text"},{"doc":"sprocket/html","title":"meta","content":"pub fn meta(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;meta /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/meta)\nSynonyms:\nsprocket/html.meta\nsprocket/html meta","url":"sprocket/html.html#meta"},{"doc":"sprocket/html","title":"meter","content":"pub fn meter(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;meter&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/meter)\nSynonyms:\nsprocket/html.meter\nsprocket/html meter","url":"sprocket/html.html#meter"},{"doc":"sprocket/html","title":"meter_text","content":"pub fn meter_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.meter(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.meter_text\nsprocket/html meter_text","url":"sprocket/html.html#meter_text"},{"doc":"sprocket/html","title":"nav","content":"pub fn nav(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;nav&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/nav)\nSynonyms:\nsprocket/html.nav\nsprocket/html nav","url":"sprocket/html.html#nav"},{"doc":"sprocket/html","title":"nav_text","content":"pub fn nav_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.nav(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.nav_text\nsprocket/html nav_text","url":"sprocket/html.html#nav_text"},{"doc":"sprocket/html","title":"noscript","content":"pub fn noscript(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;noscript&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/noscript)\nSynonyms:\nsprocket/html.noscript\nsprocket/html noscript","url":"sprocket/html.html#noscript"},{"doc":"sprocket/html","title":"noscript_text","content":"pub fn noscript_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.noscript(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.noscript_text\nsprocket/html noscript_text","url":"sprocket/html.html#noscript_text"},{"doc":"sprocket/html","title":"object","content":"pub fn object(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;object&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/object)\nSynonyms:\nsprocket/html.object\nsprocket/html object","url":"sprocket/html.html#object"},{"doc":"sprocket/html","title":"object_text","content":"pub fn object_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.object(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.object_text\nsprocket/html object_text","url":"sprocket/html.html#object_text"},{"doc":"sprocket/html","title":"ol","content":"pub fn ol(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;ol&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/ol)\nSynonyms:\nsprocket/html.ol\nsprocket/html ol","url":"sprocket/html.html#ol"},{"doc":"sprocket/html","title":"ol_text","content":"pub fn ol_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.ol(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.ol_text\nsprocket/html ol_text","url":"sprocket/html.html#ol_text"},{"doc":"sprocket/html","title":"optgroup","content":"pub fn optgroup(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;optgroup&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/optgroup)\nSynonyms:\nsprocket/html.optgroup\nsprocket/html optgroup","url":"sprocket/html.html#optgroup"},{"doc":"sprocket/html","title":"optgroup_text","content":"pub fn optgroup_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.optgroup(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.optgroup_text\nsprocket/html optgroup_text","url":"sprocket/html.html#optgroup_text"},{"doc":"sprocket/html","title":"option","content":"pub fn option(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;option&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/option)\nSynonyms:\nsprocket/html.option\nsprocket/html option","url":"sprocket/html.html#option"},{"doc":"sprocket/html","title":"option_text","content":"pub fn option_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.option(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.option_text\nsprocket/html option_text","url":"sprocket/html.html#option_text"},{"doc":"sprocket/html","title":"output","content":"pub fn output(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;output&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/output)\nSynonyms:\nsprocket/html.output\nsprocket/html output","url":"sprocket/html.html#output"},{"doc":"sprocket/html","title":"output_text","content":"pub fn output_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.output(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.output_text\nsprocket/html output_text","url":"sprocket/html.html#output_text"},{"doc":"sprocket/html","title":"p","content":"pub fn p(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;p&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/p)\nSynonyms:\nsprocket/html.p\nsprocket/html p","url":"sprocket/html.html#p"},{"doc":"sprocket/html","title":"p_text","content":"pub fn p_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.p(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.p_text\nsprocket/html p_text","url":"sprocket/html.html#p_text"},{"doc":"sprocket/html","title":"param","content":"pub fn param(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;param&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/param)\nSynonyms:\nsprocket/html.param\nsprocket/html param","url":"sprocket/html.html#param"},{"doc":"sprocket/html","title":"param_text","content":"pub fn param_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.param(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.param_text\nsprocket/html param_text","url":"sprocket/html.html#param_text"},{"doc":"sprocket/html","title":"picture","content":"pub fn picture(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;picture&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/picture)\nSynonyms:\nsprocket/html.picture\nsprocket/html picture","url":"sprocket/html.html#picture"},{"doc":"sprocket/html","title":"picture_text","content":"pub fn picture_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.picture(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.picture_text\nsprocket/html picture_text","url":"sprocket/html.html#picture_text"},{"doc":"sprocket/html","title":"pre","content":"pub fn pre(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;pre&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/pre)\nSynonyms:\nsprocket/html.pre\nsprocket/html pre","url":"sprocket/html.html#pre"},{"doc":"sprocket/html","title":"pre_text","content":"pub fn pre_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.pre(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.pre_text\nsprocket/html pre_text","url":"sprocket/html.html#pre_text"},{"doc":"sprocket/html","title":"progress","content":"pub fn progress(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;progress&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/progress)\nSynonyms:\nsprocket/html.progress\nsprocket/html progress","url":"sprocket/html.html#progress"},{"doc":"sprocket/html","title":"progress_text","content":"pub fn progress_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.progress(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.progress_text\nsprocket/html progress_text","url":"sprocket/html.html#progress_text"},{"doc":"sprocket/html","title":"q","content":"pub fn q(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;q&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/q)\nSynonyms:\nsprocket/html.q\nsprocket/html q","url":"sprocket/html.html#q"},{"doc":"sprocket/html","title":"q_text","content":"pub fn q_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.q(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.q_text\nsprocket/html q_text","url":"sprocket/html.html#q_text"},{"doc":"sprocket/html","title":"rp","content":"pub fn rp(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;rp&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/rp)\nSynonyms:\nsprocket/html.rp\nsprocket/html rp","url":"sprocket/html.html#rp"},{"doc":"sprocket/html","title":"rp_text","content":"pub fn rp_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.rp(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.rp_text\nsprocket/html rp_text","url":"sprocket/html.html#rp_text"},{"doc":"sprocket/html","title":"rt","content":"pub fn rt(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;rt&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/rt)\nSynonyms:\nsprocket/html.rt\nsprocket/html rt","url":"sprocket/html.html#rt"},{"doc":"sprocket/html","title":"rt_text","content":"pub fn rt_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.rt(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.rt_text\nsprocket/html rt_text","url":"sprocket/html.html#rt_text"},{"doc":"sprocket/html","title":"ruby","content":"pub fn ruby(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;ruby&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/ruby)\nSynonyms:\nsprocket/html.ruby\nsprocket/html ruby","url":"sprocket/html.html#ruby"},{"doc":"sprocket/html","title":"ruby_text","content":"pub fn ruby_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.ruby(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.ruby_text\nsprocket/html ruby_text","url":"sprocket/html.html#ruby_text"},{"doc":"sprocket/html","title":"s","content":"pub fn s(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;s&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/s)\nSynonyms:\nsprocket/html.s\nsprocket/html s","url":"sprocket/html.html#s"},{"doc":"sprocket/html","title":"s_text","content":"pub fn s_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.s(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.s_text\nsprocket/html s_text","url":"sprocket/html.html#s_text"},{"doc":"sprocket/html","title":"samp","content":"pub fn samp(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;samp&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/samp)\nSynonyms:\nsprocket/html.samp\nsprocket/html samp","url":"sprocket/html.html#samp"},{"doc":"sprocket/html","title":"samp_text","content":"pub fn samp_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.samp(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.samp_text\nsprocket/html samp_text","url":"sprocket/html.html#samp_text"},{"doc":"sprocket/html","title":"script","content":"pub fn script(attrs: List(Attribute), body: Option(String)) -&gt; Element\n The [HTML `&lt;script&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/script)\nSynonyms:\nsprocket/html.script\nsprocket/html script","url":"sprocket/html.html#script"},{"doc":"sprocket/html","title":"section","content":"pub fn section(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;section&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/section)\nSynonyms:\nsprocket/html.section\nsprocket/html section","url":"sprocket/html.html#section"},{"doc":"sprocket/html","title":"section_text","content":"pub fn section_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.section(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.section_text\nsprocket/html section_text","url":"sprocket/html.html#section_text"},{"doc":"sprocket/html","title":"select","content":"pub fn select(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;select&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/select)\nSynonyms:\nsprocket/html.select\nsprocket/html select","url":"sprocket/html.html#select"},{"doc":"sprocket/html","title":"select_text","content":"pub fn select_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.select(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.select_text\nsprocket/html select_text","url":"sprocket/html.html#select_text"},{"doc":"sprocket/html","title":"small","content":"pub fn small(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;small&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/small)\nSynonyms:\nsprocket/html.small\nsprocket/html small","url":"sprocket/html.html#small"},{"doc":"sprocket/html","title":"small_text","content":"pub fn small_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.small(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.small_text\nsprocket/html small_text","url":"sprocket/html.html#small_text"},{"doc":"sprocket/html","title":"source","content":"pub fn source(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;source /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/source)\nSynonyms:\nsprocket/html.source\nsprocket/html source","url":"sprocket/html.html#source"},{"doc":"sprocket/html","title":"span","content":"pub fn span(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;span&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/span)\nSynonyms:\nsprocket/html.span\nsprocket/html span","url":"sprocket/html.html#span"},{"doc":"sprocket/html","title":"span_text","content":"pub fn span_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.span(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.span_text\nsprocket/html span_text","url":"sprocket/html.html#span_text"},{"doc":"sprocket/html","title":"strong","content":"pub fn strong(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;strong&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/strong)\nSynonyms:\nsprocket/html.strong\nsprocket/html strong","url":"sprocket/html.html#strong"},{"doc":"sprocket/html","title":"strong_text","content":"pub fn strong_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.strong(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.strong_text\nsprocket/html strong_text","url":"sprocket/html.html#strong_text"},{"doc":"sprocket/html","title":"sub","content":"pub fn sub(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;sub&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/sub)\nSynonyms:\nsprocket/html.sub\nsprocket/html sub","url":"sprocket/html.html#sub"},{"doc":"sprocket/html","title":"sub_text","content":"pub fn sub_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.sub(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.sub_text\nsprocket/html sub_text","url":"sprocket/html.html#sub_text"},{"doc":"sprocket/html","title":"summary","content":"pub fn summary(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;summary&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/summary)\nSynonyms:\nsprocket/html.summary\nsprocket/html summary","url":"sprocket/html.html#summary"},{"doc":"sprocket/html","title":"summary_text","content":"pub fn summary_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.summary(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.summary_text\nsprocket/html summary_text","url":"sprocket/html.html#summary_text"},{"doc":"sprocket/html","title":"sup","content":"pub fn sup(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;sup&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/sup)\nSynonyms:\nsprocket/html.sup\nsprocket/html sup","url":"sprocket/html.html#sup"},{"doc":"sprocket/html","title":"sup_text","content":"pub fn sup_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.sup(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.sup_text\nsprocket/html sup_text","url":"sprocket/html.html#sup_text"},{"doc":"sprocket/html","title":"svg","content":"pub fn svg(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;svg&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/svg)\nSynonyms:\nsprocket/html.svg\nsprocket/html svg","url":"sprocket/html.html#svg"},{"doc":"sprocket/html","title":"svg_text","content":"pub fn svg_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.svg(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.svg_text\nsprocket/html svg_text","url":"sprocket/html.html#svg_text"},{"doc":"sprocket/html","title":"table","content":"pub fn table(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;table&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/table)\nSynonyms:\nsprocket/html.table\nsprocket/html table","url":"sprocket/html.html#table"},{"doc":"sprocket/html","title":"table_text","content":"pub fn table_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.table(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.table_text\nsprocket/html table_text","url":"sprocket/html.html#table_text"},{"doc":"sprocket/html","title":"tbody","content":"pub fn tbody(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;tbody&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/tbody)\nSynonyms:\nsprocket/html.tbody\nsprocket/html tbody","url":"sprocket/html.html#tbody"},{"doc":"sprocket/html","title":"tbody_text","content":"pub fn tbody_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.tbody(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.tbody_text\nsprocket/html tbody_text","url":"sprocket/html.html#tbody_text"},{"doc":"sprocket/html","title":"td","content":"pub fn td(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;td&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/td)\nSynonyms:\nsprocket/html.td\nsprocket/html td","url":"sprocket/html.html#td"},{"doc":"sprocket/html","title":"td_text","content":"pub fn td_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.td(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.td_text\nsprocket/html td_text","url":"sprocket/html.html#td_text"},{"doc":"sprocket/html","title":"text","content":"pub fn text(text: String) -&gt; Element\n\nSynonyms:\nsprocket/html.text\nsprocket/html text","url":"sprocket/html.html#text"},{"doc":"sprocket/html","title":"textarea","content":"pub fn textarea(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;textarea&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/textarea)\nSynonyms:\nsprocket/html.textarea\nsprocket/html textarea","url":"sprocket/html.html#textarea"},{"doc":"sprocket/html","title":"textarea_text","content":"pub fn textarea_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.textarea(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.textarea_text\nsprocket/html textarea_text","url":"sprocket/html.html#textarea_text"},{"doc":"sprocket/html","title":"tfoot","content":"pub fn tfoot(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;tfoot&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/tfoot)\nSynonyms:\nsprocket/html.tfoot\nsprocket/html tfoot","url":"sprocket/html.html#tfoot"},{"doc":"sprocket/html","title":"tfoot_text","content":"pub fn tfoot_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.tfoot(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.tfoot_text\nsprocket/html tfoot_text","url":"sprocket/html.html#tfoot_text"},{"doc":"sprocket/html","title":"th","content":"pub fn th(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;th&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/th)\nSynonyms:\nsprocket/html.th\nsprocket/html th","url":"sprocket/html.html#th"},{"doc":"sprocket/html","title":"th_text","content":"pub fn th_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.th(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.th_text\nsprocket/html th_text","url":"sprocket/html.html#th_text"},{"doc":"sprocket/html","title":"thead","content":"pub fn thead(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;thead&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/thead)\nSynonyms:\nsprocket/html.thead\nsprocket/html thead","url":"sprocket/html.html#thead"},{"doc":"sprocket/html","title":"thead_text","content":"pub fn thead_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.thead(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.thead_text\nsprocket/html thead_text","url":"sprocket/html.html#thead_text"},{"doc":"sprocket/html","title":"time","content":"pub fn time(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;time&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/time)\nSynonyms:\nsprocket/html.time\nsprocket/html time","url":"sprocket/html.html#time"},{"doc":"sprocket/html","title":"time_text","content":"pub fn time_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.time(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.time_text\nsprocket/html time_text","url":"sprocket/html.html#time_text"},{"doc":"sprocket/html","title":"title","content":"pub fn title(title: String) -&gt; Element\n The HTML [`&lt;title&gt;`](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/title) element\nSynonyms:\nsprocket/html.title\nsprocket/html title","url":"sprocket/html.html#title"},{"doc":"sprocket/html","title":"tr","content":"pub fn tr(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;tr&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/tr)\nSynonyms:\nsprocket/html.tr\nsprocket/html tr","url":"sprocket/html.html#tr"},{"doc":"sprocket/html","title":"tr_text","content":"pub fn tr_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.tr(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.tr_text\nsprocket/html tr_text","url":"sprocket/html.html#tr_text"},{"doc":"sprocket/html","title":"track","content":"pub fn track(attrs: List(Attribute)) -&gt; Element\n The [HTML `&lt;track /&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/track)\nSynonyms:\nsprocket/html.track\nsprocket/html track","url":"sprocket/html.html#track"},{"doc":"sprocket/html","title":"u","content":"pub fn u(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;u&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/u)\nSynonyms:\nsprocket/html.u\nsprocket/html u","url":"sprocket/html.html#u"},{"doc":"sprocket/html","title":"u_text","content":"pub fn u_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.u(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.u_text\nsprocket/html u_text","url":"sprocket/html.html#u_text"},{"doc":"sprocket/html","title":"ul","content":"pub fn ul(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;ul&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/ul)\nSynonyms:\nsprocket/html.ul\nsprocket/html ul","url":"sprocket/html.html#ul"},{"doc":"sprocket/html","title":"ul_text","content":"pub fn ul_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.ul(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.ul_text\nsprocket/html ul_text","url":"sprocket/html.html#ul_text"},{"doc":"sprocket/html","title":"var","content":"pub fn var(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;var&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/var)\nSynonyms:\nsprocket/html.var\nsprocket/html var","url":"sprocket/html.html#var"},{"doc":"sprocket/html","title":"var_text","content":"pub fn var_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.var(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.var_text\nsprocket/html var_text","url":"sprocket/html.html#var_text"},{"doc":"sprocket/html","title":"video","content":"pub fn video(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;video&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/video)\nSynonyms:\nsprocket/html.video\nsprocket/html video","url":"sprocket/html.html#video"},{"doc":"sprocket/html","title":"video_text","content":"pub fn video_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.video(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.video_text\nsprocket/html video_text","url":"sprocket/html.html#video_text"},{"doc":"sprocket/html","title":"wbr","content":"pub fn wbr(attrs: List(Attribute), children: List(Element)) -&gt; Element\n The [HTML `&lt;wbr&gt;` element](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/wbr)\nSynonyms:\nsprocket/html.wbr\nsprocket/html wbr","url":"sprocket/html.html#wbr"},{"doc":"sprocket/html","title":"wbr_text","content":"pub fn wbr_text(attrs: List(Attribute), text inner_text: String) -&gt; Element\n Shorthand for `html.wbr(attrs, children: [html.text(text)])`\nSynonyms:\nsprocket/html.wbr_text\nsprocket/html wbr_text","url":"sprocket/html.html#wbr_text"},{"doc":"sprocket/html","title":"sprocket/html","content":"","url":"sprocket/html.html"},{"doc":"sprocket/hooks/state","title":"state","content":"pub fn state(ctx: Context, initial: a, cb: fn(\n    Context,\n    a,\n    fn(a) -&gt; Nil,\n  ) -&gt; #(Context, List(Element))) -&gt; #(Context, List(Element))\n\nSynonyms:\nsprocket/hooks/state.state\nsprocket/hooks/state state","url":"sprocket/hooks/state.html#state"},{"doc":"sprocket/hooks/state","title":"sprocket/hooks/state","content":"","url":"sprocket/hooks/state.html"},{"doc":"sprocket/hooks/effect","title":"effect","content":"pub fn effect(ctx: Context, effect_fn: fn() -&gt;\n    Option(fn() -&gt; Nil), trigger: HookTrigger, cb: fn(Context) -&gt;\n    #(Context, List(Element))) -&gt; #(Context, List(Element))\n\nSynonyms:\nsprocket/hooks/effect.effect\nsprocket/hooks/effect effect","url":"sprocket/hooks/effect.html#effect"},{"doc":"sprocket/hooks/effect","title":"sprocket/hooks/effect","content":"","url":"sprocket/hooks/effect.html"},{"doc":"sprocket/sprocket","title":"Message","content":"pub type Message {\n  Shutdown\n  GetRendered(reply_with: Subject(Option(RenderedElement)))\n  HasWebSocket(reply_with: Subject(Bool), websocket: WebSocket)\n  SetRenderUpdate(fn() -&gt; Nil)\n  Render(reply_with: Subject(RenderedElement))\n  RenderUpdate\n  SetUpdateHook(fn(Unique, fn(Hook) -&gt; Hook) -&gt; Nil)\n  UpdateHook(Unique, fn(Hook) -&gt; Hook)\n  GetEventHandler(\n    reply_with: Subject(Result(EventHandler, Nil)),\n    id: Unique,\n  )\n}\n\nShutdown\n\n\nGetRendered(reply_with: Subject(Option(RenderedElement)))\n\n\nHasWebSocket(reply_with: Subject(Bool), websocket: WebSocket)\n\n\nSetRenderUpdate(fn() -&gt; Nil)\n\n\nRender(reply_with: Subject(RenderedElement))\n\n\nRenderUpdate\n\n\nSetUpdateHook(fn(Unique, fn(Hook) -&gt; Hook) -&gt; Nil)\n\n\nUpdateHook(Unique, fn(Hook) -&gt; Hook)\n\n\nGetEventHandler(\n  reply_with: Subject(Result(EventHandler, Nil)),\n  id: Unique,\n)\n\n\nSynonyms:\nsprocket/sprocket.Message\nsprocket/sprocket Message","url":"sprocket/sprocket.html#Message"},{"doc":"sprocket/sprocket","title":"Sprocket","content":"pub type Sprocket =\n  Subject(Message)\n\n\nSynonyms:\nsprocket/sprocket.Sprocket\nsprocket/sprocket Sprocket","url":"sprocket/sprocket.html#Sprocket"},{"doc":"sprocket/sprocket","title":"get_handler","content":"pub fn get_handler(actor: Subject(Message), id: String) -&gt; Result(\n  EventHandler,\n  Nil,\n)\n Get the event handler for a given id\nSynonyms:\nsprocket/sprocket.get_handler\nsprocket/sprocket get_handler","url":"sprocket/sprocket.html#get_handler"},{"doc":"sprocket/sprocket","title":"get_rendered","content":"pub fn get_rendered(actor: Subject(Message)) -&gt; Option(\n  RenderedElement,\n)\n Get the previously rendered view from the actor\nSynonyms:\nsprocket/sprocket.get_rendered\nsprocket/sprocket get_rendered","url":"sprocket/sprocket.html#get_rendered"},{"doc":"sprocket/sprocket","title":"has_websocket","content":"pub fn has_websocket(actor: Subject(Message), websocket: Subject(\n    HandlerMessage,\n  )) -&gt; Bool\n Returns true if the actor matches a given websocket connection\nSynonyms:\nsprocket/sprocket.has_websocket\nsprocket/sprocket has_websocket","url":"sprocket/sprocket.html#has_websocket"},{"doc":"sprocket/sprocket","title":"render","content":"pub fn render(actor: Subject(Message)) -&gt; RenderedElement\n Render the view\nSynonyms:\nsprocket/sprocket.render\nsprocket/sprocket render","url":"sprocket/sprocket.html#render"},{"doc":"sprocket/sprocket","title":"render_update","content":"pub fn render_update(actor: Subject(Message)) -&gt; Nil\n Render the view and send an update Patch to the updater\nSynonyms:\nsprocket/sprocket.render_update\nsprocket/sprocket render_update","url":"sprocket/sprocket.html#render_update"},{"doc":"sprocket/sprocket","title":"start","content":"pub fn start(ws: Option(Subject(HandlerMessage)), view: Option(\n    Element,\n  ), updater: Option(Updater(Patch))) -&gt; Subject(Message)\n Start a new sprocket actor\nSynonyms:\nsprocket/sprocket.start\nsprocket/sprocket start","url":"sprocket/sprocket.html#start"},{"doc":"sprocket/sprocket","title":"stop","content":"pub fn stop(actor: Subject(Message)) -&gt; Nil\n Stop a sprocket actor\nSynonyms:\nsprocket/sprocket.stop\nsprocket/sprocket stop","url":"sprocket/sprocket.html#stop"},{"doc":"sprocket/sprocket","title":"sprocket/sprocket","content":"","url":"sprocket/sprocket.html"},{"doc":"sprocket/cassette","title":"Cassette","content":"pub type Cassette =\n  Subject(Message)\n\n\nSynonyms:\nsprocket/cassette.Cassette\nsprocket/cassette Cassette","url":"sprocket/cassette.html#Cassette"},{"doc":"sprocket/cassette","title":"CassetteOpts","content":"pub type CassetteOpts {\n  CassetteOpts(debug: Bool)\n}\n\nCassetteOpts(debug: Bool)\n\n\nSynonyms:\nsprocket/cassette.CassetteOpts\nsprocket/cassette CassetteOpts","url":"sprocket/cassette.html#CassetteOpts"},{"doc":"sprocket/cassette","title":"Message","content":"pub type Message {\n  Shutdown\n  GetState(reply_with: Subject(State))\n  PushPreflight(preflight: Preflight)\n  CleanupPreflights\n  StartPreflightCleanupJob(cleanup_preflights: fn() -&gt; Nil)\n  PopPreflight(\n    reply_with: Subject(Result(Preflight, Nil)),\n    id: String,\n  )\n  PushSprocket(sprocket: Sprocket)\n  GetSprocket(\n    reply_with: Subject(Result(Sprocket, Nil)),\n    ws: WebSocket,\n  )\n  PopSprocket(\n    reply_with: Subject(Result(Sprocket, Nil)),\n    ws: WebSocket,\n  )\n}\n\nShutdown\n\n\nGetState(reply_with: Subject(State))\n\n\nPushPreflight(preflight: Preflight)\n\n\nCleanupPreflights\n\n\nStartPreflightCleanupJob(cleanup_preflights: fn() -&gt; Nil)\n\n\nPopPreflight(\n  reply_with: Subject(Result(Preflight, Nil)),\n  id: String,\n)\n\n\nPushSprocket(sprocket: Sprocket)\n\n\nGetSprocket(\n  reply_with: Subject(Result(Sprocket, Nil)),\n  ws: WebSocket,\n)\n\n\nPopSprocket(\n  reply_with: Subject(Result(Sprocket, Nil)),\n  ws: WebSocket,\n)\n\n\nSynonyms:\nsprocket/cassette.Message\nsprocket/cassette Message","url":"sprocket/cassette.html#Message"},{"doc":"sprocket/cassette","title":"Preflight","content":"pub type Preflight {\n  Preflight(\n    id: String,\n    view: Element,\n    csrf_token: String,\n    created_at: Int,\n  )\n}\n\nPreflight(\n  id: String,\n  view: Element,\n  csrf_token: String,\n  created_at: Int,\n)\n\n\nSynonyms:\nsprocket/cassette.Preflight\nsprocket/cassette Preflight","url":"sprocket/cassette.html#Preflight"},{"doc":"sprocket/cassette","title":"State","content":"pub type State {\n  State(\n    sprockets: List(Sprocket),\n    preflights: List(Preflight),\n    cancel_preflight_cleanup_job: fn() -&gt; Nil,\n    debug: Bool,\n  )\n}\n\nState(\n  sprockets: List(Sprocket),\n  preflights: List(Preflight),\n  cancel_preflight_cleanup_job: fn() -&gt; Nil,\n  debug: Bool,\n)\n\n\nSynonyms:\nsprocket/cassette.State\nsprocket/cassette State","url":"sprocket/cassette.html#State"},{"doc":"sprocket/cassette","title":"get_state","content":"pub fn get_state(ca: Subject(Message)) -&gt; State\n\nSynonyms:\nsprocket/cassette.get_state\nsprocket/cassette get_state","url":"sprocket/cassette.html#get_state"},{"doc":"sprocket/cassette","title":"live_service","content":"pub fn live_service(_req: Request(Body), ca: Subject(Message)) -&gt; HandlerResponse\n\nSynonyms:\nsprocket/cassette.live_service\nsprocket/cassette live_service","url":"sprocket/cassette.html#live_service"},{"doc":"sprocket/cassette","title":"pop_preflight","content":"pub fn pop_preflight(ca: Subject(Message), id: String) -&gt; Result(\n  Preflight,\n  Nil,\n)\n\nSynonyms:\nsprocket/cassette.pop_preflight\nsprocket/cassette pop_preflight","url":"sprocket/cassette.html#pop_preflight"},{"doc":"sprocket/cassette","title":"push_preflight","content":"pub fn push_preflight(ca: Subject(Message), preflight: Preflight) -&gt; Preflight\n\nSynonyms:\nsprocket/cassette.push_preflight\nsprocket/cassette push_preflight","url":"sprocket/cassette.html#push_preflight"},{"doc":"sprocket/cassette","title":"start","content":"pub fn start(opts: Option(CassetteOpts)) -&gt; Subject(Message)\n\nSynonyms:\nsprocket/cassette.start\nsprocket/cassette start","url":"sprocket/cassette.html#start"},{"doc":"sprocket/cassette","title":"stop","content":"pub fn stop(ca: Subject(Message)) -&gt; Nil\n\nSynonyms:\nsprocket/cassette.stop\nsprocket/cassette stop","url":"sprocket/cassette.html#stop"},{"doc":"sprocket/cassette","title":"sprocket/cassette","content":"","url":"sprocket/cassette.html"},{"doc":"sprocket","title":"main","content":"pub fn main() -&gt; Nil\n The main function is the entry point of the docs demo\nSynonyms:\nsprocket.main\nsprocket main","url":"sprocket.html#main"},{"doc":"sprocket","title":"sprocket","content":"","url":"sprocket.html"},{"doc":"test_helpers","title":"Event","content":"pub type Event {\n  ClickEvent\n}\n\nClickEvent\n\n\nSynonyms:\ntest_helpers.Event\ntest_helpers Event","url":"test_helpers.html#Event"},{"doc":"test_helpers","title":"live","content":"pub fn live(view: Element) -&gt; Subject(Message)\n\nSynonyms:\ntest_helpers.live\ntest_helpers live","url":"test_helpers.html#live"},{"doc":"test_helpers","title":"render_event","content":"pub fn render_event(spkt: Subject(Message), event: Event, html_id: String) -&gt; Subject(\n  Message,\n)\n\nSynonyms:\ntest_helpers.render_event\ntest_helpers render_event","url":"test_helpers.html#render_event"},{"doc":"test_helpers","title":"render_html","content":"pub fn render_html(spkt: Subject(Message)) -&gt; #(\n  Subject(Message),\n  String,\n)\n\nSynonyms:\ntest_helpers.render_html\ntest_helpers render_html","url":"test_helpers.html#render_html"},{"doc":"test_helpers","title":"test_helpers","content":"","url":"test_helpers.html"}]);